::: laktory.models.resources.databricks.ExternalLocation

---

::: laktory.models.resources.databricks.externallocation.ExternalLocationEncryptionDetailsSseEncryptionDetails

---

::: laktory.models.resources.databricks.externallocation.ExternalLocationEncryptionDetails
